@@ -14,18 +14,9 @@ import os
 
 from random import randint
 from time import time
+from typing import List
 
 import pygame as pg
-from pygame.compat import xrange_
-
-
-if "-psyco" in sys.argv:
-    try:
-        import psyco
-
-        psyco.full()
-    except Exception:
-        print("No psyco for you!  psyco failed to import and run.")
 
 main_dir = os.path.split(os.path.abspath(__file__))[0]
 data_dir = os.path.join(main_dir, "data")
@@ -79,10 +70,7 @@ if "-width" in sys.argv:
     i = sys.argv.index("-width")
     screen_dims[0] = int(sys.argv[i + 1])
 
-if "-alpha" in sys.argv:
-    use_alpha = True
-else:
-    use_alpha = False
+use_alpha = "-alpha" in sys.argv
 
 print(screen_dims)
 
@@ -108,7 +96,7 @@ print(screen_dims)
 
 
 class Thingy(pg.sprite.DirtySprite):
-    images = None
+    images: List[pg.Surface] = []
 
     def __init__(self):
         ##        pg.sprite.Sprite.__init__(self)
@@ -121,7 +109,7 @@ class Thingy(pg.sprite.DirtySprite):
         self.vel = [randint(-1, 1), randint(-1, 1)]
         self.dirty = 2
 
-    def update(self):
+    def update(self, *args, **kwargs):
         for i in [0, 1]:
             nv = self.rect[i] + self.vel[i]
             if nv >= screen_dims[i] or nv < 0:
@@ -131,21 +119,21 @@ class Thingy(pg.sprite.DirtySprite):
 
 
 class Static(pg.sprite.DirtySprite):
-    images = None
+    images: List[pg.Surface] = []
 
     def __init__(self):
         pg.sprite.DirtySprite.__init__(self)
         self.image = Static.images[0]
         self.rect = self.image.get_rect()
-        self.rect.x = randint(0, 3 * screen_dims[0] / 4)
-        self.rect.y = randint(0, 3 * screen_dims[1] / 4)
+        self.rect.x = randint(0, 3 * screen_dims[0] // 4)
+        self.rect.y = randint(0, 3 * screen_dims[1] // 4)
 
 
 def main(
     update_rects=True,
     use_static=False,
     use_layered_dirty=False,
-    screen_dims=[640, 480],
+    screen_dims=(640, 480),
     use_alpha=False,
     flags=0,
 ):
@@ -218,7 +206,7 @@ def main(
         else:
             sprites = pg.sprite.Group()
 
-    for i in xrange_(0, numsprites):
+    for i in range(0, numsprites):
         if use_static and i % 2 == 0:
             sprites.add(Static())
         sprites.add(Thingy())
@@ -254,7 +242,7 @@ def main(
 
         frames += 1
     end = time()
-    print("FPS: %f" % (frames / ((end - start))))
+    print(f"FPS: {frames / (end - start):f}")
     pg.quit()
 
 
