@@ -28,7 +28,6 @@ def intensity(c, i):
 
 
 class GfxdrawDefaultTest(unittest.TestCase):
-
     is_started = False
 
     foreground_color = (128, 64, 8)
@@ -630,7 +629,7 @@ class GfxdrawDefaultTest(unittest.TestCase):
                 self.assertEqual(
                     expected_surface.get_at((x, y)),
                     surface.get_at((x, y)),
-                    "pos=({}, {})".format(x, y),
+                    f"pos=({x}, {y})",
                 )
 
         surface.unlock()
@@ -763,7 +762,7 @@ class GfxdrawDefaultTest(unittest.TestCase):
                 self.assertEqual(
                     expected_surface.get_at((x, y)),
                     surface.get_at((x, y)),
-                    "pos=({}, {})".format(x, y),
+                    f"pos=({x}, {y})",
                 )
 
         surface.unlock()
